changeset 4586:7e08de0d1a98

[project @ 2003-11-08 06:32:17 by jwe]
author jwe
date Sat, 08 Nov 2003 06:32:17 +0000
parents a1ac9ab474a1
children 7b957b442818
files liboctave/Array.cc
diffstat 1 files changed, 10 insertions(+), 10 deletions(-) [+]
line wrap: on
line diff
--- a/liboctave/Array.cc
+++ b/liboctave/Array.cc
@@ -1738,9 +1738,9 @@
 
   if (ra_idx.is_colon ())
     {
-      dim_vector idx (orig_len);
-
-      retval = Array<T> (*this, idx);
+      dim_vector iidx (orig_len);
+
+      retval = Array<T> (*this, iidx);
     }
   else if (length () == 1)
     {
@@ -1865,18 +1865,18 @@
         {
 	  int r_idx = ra_idx(0);
 
-          Array<int> idx = get_ra_idx (r_idx, dims ());
+          Array<int> iidx = get_ra_idx (r_idx, dims ());
 
           dim_vector new_dims (1);
 
 	  // This shouldn't be needed.
 
-	  Array<int> e (idx.length ());
-
-	  for (int i = 0; i < idx.length();i++)
-	    e(i) = idx(i);
-
-	  // Should be able to call elem (idx).
+	  Array<int> e (iidx.length ());
+
+	  for (int i = 0; i < iidx.length();i++)
+	    e(i) = iidx(i);
+
+	  // Should be able to call elem (iidx).
 
           retval = Array<T> (new_dims, elem (e));
 	}